import {
  computed,
  ref,
  defineComponent,
  onMounted,
  reactive,
  onUnmounted,
  watch,
  onBeforeMount
} from 'vue'
import {
  Card,
  Cell,
  CellGroup,
  Checkbox,
  Popup,
  Radio,
  SubmitBar,
  Toast
} from 'vant'
import { addressType, cartConfirm, formateAttr } from '../cart'
import styles from '../index.module.less'
import Address from '../components/address'
import request from '@/helpers/request'
import { useRoute, useRouter } from 'vue-router'
import ColProtocol from '@/components/col-protocol'
import Payment from '@/views/order-detail/payment'
import { state } from '@/state'
import ColPopup from '@/components/col-popup'
import UserAuth from '@/views/order-detail/userAuth'
import ColResult from '@/components/col-result'
import { moneyFormat } from '@/helpers/utils'
import {
  listenerMessage,
  postMessage,
  removeListenerMessage
} from '@/helpers/native-message'
import UseCoupons from '@/views/order-detail/use-coupons'
import { addressInfo, resestState } from '@/views/address/address'
import { orderInfos } from '@/views/order-detail/orderStatus'
import ColHeader from '@/components/col-header'
export default defineComponent({
  name: 'cartConfirm',
  setup() {
    const loading = ref(true)
    const route = useRoute()
    const address = ref<addressType>()
    const cartUseAmount = ref<any>({
      useBalance: false,
      balance: 0,
      couponId: ''
    })
    const paymentWay = ref([])
    onMounted(async () => {
      loading.value = true
      // 获取用户余额
      await getUserBalance()
      if (route.query.cartIds) {
        try {
          const { code, data } = await request.post(
            '/api-mall-portal/order/generateConfirmOrder',
            {
              params: {
                cartIds: route.query.cartIds
              }
            }
          )
          if (code === 200) {
            cartConfirm.calcAmount = data.calcAmount
            cartConfirm.cartPromotionItemList = data.cartPromotionItemList
            cartConfirm.memberReceiveAddressList = data.memberReceiveAddressList
          }

          const res = await request.get(
            '/api-student/sysConfig/queryByParamName',
            {
              params: {
                paramName: 'payment_channel_action'
              }
            }
          )
          const paranValue = res.data.paranValue
          paymentWay.value = paranValue ? JSON.parse(paranValue) : []
        } catch (error) {}
      }
      loading.value = false
      if (cartConfirm.memberReceiveAddressList.length) {
        const a =
          cartConfirm.memberReceiveAddressList.find(
            (n: any) => n.defaultStatus
          ) || cartConfirm.memberReceiveAddressList[0]
        if (a) address.value = a
      }
      // 判断是否有数据
      if (addressInfo.id) {
        setAddress({ ...addressInfo } || {})
        resestState()
      }
    })

    // 获取用户余额
    const getUserBalance = async () => {
      try {
        // 获取用户余额
        const { data } = await request.get('/api-student/userCashAccount/get')
        cartUseAmount.value.balance = data.balance || 0
      } catch {}
    }

    const setAddress = (result: addressType) => {
      address.value = result
    }

    const agreeStatus = ref(false)
    const paymentPopup = ref(false)
    const authPopup = ref(false)
    const orderInfo = ref<any>()
    //修复实名认证头部问题
    // watch(authPopup, (value, oldValue) => {
    //   if (authPopup.value) {
    //     // 设置是否显示导航栏 0 显示 1 不显示
    //     postMessage({ api: 'setBarStatus', content: { status: 0 } })
    //   } else {
    //     postMessage({ api: 'setBarStatus', content: { status: 1 } })
    //   }
    // })
    // 提交
    const onSubmit = () => {
      if (!address.value?.id) {
        Toast('请选择收货地址')
        return
      }
      if (!agreeStatus.value) {
        Toast('请先阅读并同意《产品及服务协议》')
        return
      }
      const users = state.user.data
      // 判断是否需要实名认证
      if (!users?.student.realName || !users?.student.idCardNo) {
        authPopup.value = true
        return
      }

      createOrder()
    }
    const router = useRouter()
    //创建订单
    const createOrder = async () => {
      const ids = cartConfirm.cartPromotionItemList.reduce(
        (arr, value: any) => {
          arr.push(value.id)
          return arr
        },
        []
      )

      const payAmount =
        cartConfirm.calcAmount.payAmount -
        cartConfirm.calcAmount.promotionAmount
      const body = {
        cartIds: ids,
        memberReceiveAddressId: address.value?.id,
        platformType: state.platformType,
        orderAmount: Number((payAmount >= 0 ? payAmount : 0).toFixed(2)),
        couponId: cartUseAmount.value.couponId,
        useBalance: cartUseAmount.value.useBalance // 是否使用余额
      }
      try {
        const { code, data } = await request.post(
          '/api-mall-portal/order/generateOrder',
          { data: body }
        )
        if (code === 200) {
          if (data.order.status === 1) {
            router.replace({
              path: `/shopTrade`,
              query: {
                orderNo: data?.order.orderSn,
                id: data?.order.id
              }
            })
            return
          }
          paymentPopup.value = true
          // orderInfo.orderNo = data?.order.orderSn || ''
          // orderInfo.actualPrice = data?.order.payAmount || 0
          orderInfo.value = data?.pay
        }
      } catch (error) {}
    }

    //认证成功
    const onAuthSuccess = () => {
      authPopup.value = false
      console.log(state.user.data)
      onSubmit() // 实名成功后自动支付
    }

    // {
    //   moneyFormat(
    //     cartConfirm.calcAmount.payAmount -
    //       cartConfirm.calcAmount.promotionAmount
    //   )
    // }
    const needPayPrice = () => {
      const payAmount =
        cartConfirm.calcAmount.payAmount -
        cartConfirm.calcAmount.promotionAmount
      let price = Number((payAmount >= 0 ? payAmount : 0).toFixed(2))
      console.log(price)
      if (cartUseAmount.value.useBalance) {
        price =
          price - cartUseAmount.value.balance <= 0
            ? 0
            : Number((price - cartUseAmount.value.balance).toFixed(2))
      }

      return price
    }
    return () => (
      <>
        <ColHeader />
        {loading.value ? null : (
          <div>
            {cartConfirm.cartPromotionItemList.length ? (
              <div class={styles.cartConfirm}>
                <div class={styles.cartConfirmBox}>
                  <Address item={address.value} setAddress={setAddress} />
                </div>
                <div
                  style={{ marginTop: '20px' }}
                  class={[styles.cartBox, styles.cartConfirmBox]}
                >
                  <div class={styles.shopBox}>
                    {cartConfirm.cartPromotionItemList.map((item: any) => (
                      <div
                        class={[styles.cartItem]}
                        style={{ marginBottom: '10px' }}
                      >
                        <Card
                          price={moneyFormat(item.price)}
                          desc={formateAttr(item.productAttr)}
                          title={item.productName}
                          thumb={item.productPic}
                          num={item.quantity}
                        ></Card>
                      </div>
                    ))}
                  </div>
                  <CellGroup border={true}>
                    <UseCoupons
                      useSystem="MALL"
                      typeDetail="MALLCOUPON"
                      orderAmount={cartConfirm.calcAmount.totalAmount}
                      onCouponSelect={coupon => {
                        console.log(coupon, 'coupon')
                        const discountPrice = coupon
                          .map(n => n.faceValue)
                          .reduce((total, n) => {
                            return total + n
                          }, 0)
                        const couponId = coupon
                          .map(n => n.couponCodeId)
                          .join(',')
                        cartConfirm.calcAmount.promotionAmount = discountPrice
                        cartUseAmount.value.couponId = couponId

                        console.log(cartUseAmount, 'coupon')
                        // orderInfo.couponId = couponId
                      }}
                    />

                    <Cell
                      v-slots={{
                        title: `余额支付（剩余：￥${moneyFormat(
                          cartUseAmount.value.balance
                        )}）`,
                        'right-icon': () => (
                          <Checkbox
                            modelValue={cartUseAmount.value.useBalance}
                          />
                        )
                      }}
                      onClick={() => {
                        console.log(true, '111')
                        cartUseAmount.value.useBalance =
                          !cartUseAmount.value.useBalance
                      }}
                    />

                    <Cell
                      border={false}
                      title="总额"
                      value={
                        '¥ ' + moneyFormat(cartConfirm.calcAmount.totalAmount)
                      }
                    ></Cell>
                  </CellGroup>
                </div>

                <div class={styles.payProtocol}>
                  <ColProtocol
                    showHeader
                    v-model={agreeStatus.value}
                  ></ColProtocol>
                  <SubmitBar
                    buttonText={`结算(${cartConfirm.cartPromotionItemList.length})`}
                    buttonColor="var(--van-primary)"
                    disabled={cartConfirm.cartPromotionItemList.length === 0}
                    onSubmit={() => onSubmit()}
                  >
                    <div class={styles.confirmBottom}>
                      合计{' '}
                      <span class={styles['price-des']}>
                        ¥{moneyFormat(needPayPrice())}
                      </span>
                    </div>
                  </SubmitBar>
                </div>

                <div style={{ height: 'var(--van-submit-bar-height)' }}></div>
                <ColPopup v-model={authPopup.value}>
                  <UserAuth onSuccess={onAuthSuccess} />
                </ColPopup>
                <Popup
                  show={paymentPopup.value}
                  closeOnClickOverlay={false}
                  position="bottom"
                  round
                  closeOnPopstate
                  safeAreaInsetBottom
                  style={{ minHeight: '30%' }}
                >
                  <Payment
                    paymentWay={paymentWay.value}
                    v-model={paymentPopup.value}
                    orderInfo={orderInfo.value}
                    paymentType="goodsPay"
                    onBackOut={() => (paymentPopup.value = false)}
                  />
                </Popup>
              </div>
            ) : (
              <ColResult
                buttonText="去购物车"
                onClick={() => {
                  router.push({ path: '/cart' })
                }}
              ></ColResult>
            )}
          </div>
        )}
      </>
    )
  }
})
